@@ -2108,6 +2108,39 @@ mms_message_status_get_string (enum mms_message_status status)
       return "draft";
     case MMS_MESSAGE_STATUS_DELIVERED:
       return "delivered";
+    case MMS_MESSAGE_STATUS_SENDING_FAILED:
+      return "sending_failed";
+    }
+
+  return NULL;
+}
+
+const char *
+message_rsp_status_to_string (
+  enum mms_message_rsp_status status)
+{
+  switch (status)
+    {
+    case MMS_MESSAGE_RSP_STATUS_OK:
+      return "ok";
+    case MMS_MESSAGE_RSP_STATUS_ERR_UNSUPPORTED_MESSAGE:
+      return "error-unsupported-message";
+    case MMS_MESSAGE_RSP_STATUS_ERR_TRANS_FAILURE:
+      return "error-transient-failure";
+    case MMS_MESSAGE_RSP_STATUS_ERR_TRANS_NETWORK_PROBLEM:
+      return "error-transient-network-problem";
+    case MMS_MESSAGE_RSP_STATUS_ERR_PERM_FAILURE:
+      return "error-permanent-failure";
+    case MMS_MESSAGE_RSP_STATUS_ERR_PERM_SERVICE_DENIED:
+      return "error-permanent-service-denied";
+    case MMS_MESSAGE_RSP_STATUS_ERR_PERM_MESSAGE_FORMAT_CORRUPT:
+      return "error-permanent-message-format-corrupt";
+    case MMS_MESSAGE_RSP_STATUS_ERR_PERM_SENDING_ADDRESS_UNRESOLVED:
+      return "error-permanent-sending-address-unresolved";
+    case MMS_MESSAGE_RSP_STATUS_ERR_PERM_CONTENT_NOT_ACCEPTED:
+      return "error-permanent-content-not-accepted";
+    case MMS_MESSAGE_RSP_STATUS_ERR_PERM_LACK_OF_PREPAID:
+      return "error-permanent-lack-of-prepaid";
     }
 
   return NULL;
